summaryrefslogtreecommitdiffstats
path: root/src/channels.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/channels.c')
-rw-r--r--src/channels.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/channels.c b/src/channels.c
index 1766f7a1..e38d9141 100644
--- a/src/channels.c
+++ b/src/channels.c
@@ -3523,9 +3523,9 @@ error:
}
/**
- * @brief Send an exit signal to remote process (as described in RFC 4254, section 6.10).
+ * @brief Send an exit signal to remote process (RFC 4254, section 6.10).
*
* Sends a signal 'sig' to the remote process.
* Note, that remote system may not support signals concept.
* In such a case this request will be silently ignored.
* Only SSH-v2 is supported (I'm not sure about SSH-v1).
@@ -3603,7 +3603,7 @@ int ssh_channel_request_send_exit_signal(ssh_channel channel, const char *sig,
goto error;
}
- rc = channel_request(channel, "signal", buffer, 0);
+ rc = channel_request(channel, "exit-signal", buffer, 0);
error:
ssh_buffer_free(buffer);
if(tmp)
@@ -3523,9 +3523,9 @@ error:
*
- * Sends a signal 'sig' to the remote process.
+ * This sends the exit status of the remote process.
* Note, that remote system may not support signals concept.
* In such a case this request will be silently ignored.